"use client";

import { Step, type StepItem, Stepper } from "@/components/stepper";
import { Alert, AlertDescription, AlertTitle } from "@/components/ui/alert";
import { Button } from "@/components/ui/button";
import { Card } from "@/components/ui/card";
import { ArrowRight, X } from "lucide-react";
import Image from "next/image";
import { useCallback, useState } from "react";
// import { FileUploader } from "react-drag-drop-files";
import { useDropzone } from "react-dropzone";

const steps = [
  { label: "Upload extraction.zip" },
  { label: "Result of analysis" },
  { label: "Course recommendation" },
] satisfies StepItem[];

// const fileTypes = ["JPEG", "PNG", "GIF"];
const Page = () => {
  const [uploadedFiles, setUploadedFiles] = useState<
    { file: File; preview: string; size: string }[]
  >([]);
  //   const [uploadedFiles, setUploadedFiles] = useState<File[]>([]);
  //   const [preview, setPreview] = useState<(string | ArrayBuffer | null)[]>([]);

  const onDrop = useCallback((acceptedFiles: Array<File>) => {
    console.log(acceptedFiles);
    console.log(acceptedFiles[0].size / 1024);

    acceptedFiles.forEach((f) => {
      const file = new FileReader();

      file.onload = function () {
        let fileSize = "";

        if (f.size < 1024) {
          // File size is less than 1KB
          fileSize = `${f.size} bytes`;
        } else if (f.size < 1024 * 1024) {
          // File size is less than 1MB
          fileSize = `${(f.size / 1024).toFixed(2)} kb`;
        } else {
          // File size is in MB
          fileSize = `${(f.size / (1024 * 1024)).toFixed(2)} mb`;
        }

        setUploadedFiles((uploadFile) => [
          ...uploadFile,
          { file: f, preview: file.result as string, size: fileSize },
        ]);
      };

      file.readAsDataURL(f);
    });
  }, []);

  const { getRootProps, getInputProps } = useDropzone({
    onDrop,
  });

  return (
    <div className="flex-1 space-y-8  p-4 md:p-8 pt-6 md:pt-10">
      <div className="flex w-full flex-col gap-4">
        <Stepper initialStep={0} steps={steps} variant="circle-alt">
          {steps.map((stepProps, index) => {
            return <Step key={stepProps.label} {...stepProps}></Step>;
          })}
        </Stepper>
      </div>

      <Alert className="py-6 space-y-2 bg-secondary">
        <AlertTitle className="text-xl font-bold">Please upload the extraction.zip file</AlertTitle>
        <AlertDescription>
          You should have a script that creates it.
        </AlertDescription>
      </Alert>

      <div
        {...getRootProps()}
        className="border border-dashed min-h-40 rounded-md relative cursor-pointer p-4"
      >
        <input {...getInputProps()} />
        <div className="flex gap-4 flex-wrap">
          {uploadedFiles.length !== 0 ? (
            uploadedFiles.map((f, i) => (
              <div key={i} className="w-28 h-full">
                <div className="relative w-28 h-28">
                  <Image
                    src={(f.preview || "") as string}
                    alt=""
                    fill
                    className="object-cover rounded"
                  />
                  <button
                    onClick={(e) => {
                      e.stopPropagation();
                      setUploadedFiles((files) => {
                        return files.filter(
                          (file) => file.file.name !== f.file.name
                        );
                      });
                    }}
                    className="absolute top-1 right-1 p-1 bg-background rounded-md text-foreground"
                  >
                    <X className="size-4 text-rose-100" />
                  </button>
                </div>
                <p className="truncate">{f.file.name}</p>
                <p className="text-sm text-muted-foreground">{f.size}</p>
              </div>
            ))
          ) : (
            <p className="absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2">
              Drag and drop files here or click to browse.
            </p>
          )}
        </div>
      </div>

      <Button size="lg" className="inline-flex items-center gap-2"> <ArrowRight/> Start Analysis</Button>
    </div>
  );
};

export default Page;
